@@ -2,13 +2,13 @@ from fief.db.main import main_async_session_maker
 from fief.db.workspace import get_workspace_session
 from fief.dependencies.users import get_user_db, get_user_manager
 from fief.locale import get_preferred_translations
-from fief.managers import (
-    ClientManager,
-    TenantManager,
-    WorkspaceManager,
-    WorkspaceUserManager,
-)
 from fief.models import Client, User, Workspace, WorkspaceUser
+from fief.repositories import (
+    ClientRepository,
+    TenantRepository,
+    WorkspaceRepository,
+    WorkspaceUserRepository,
+)
 from fief.schemas.user import UserCreateInternal
 from fief.schemas.workspace import WorkspaceCreate
 from fief.services.workspace_db import WorkspaceDatabase
@@ -42,8 +42,8 @@ class CreateMainFiefUserError(MainWorkspaceError):
 
 async def get_main_fief_workspace() -> Workspace:
     async with main_async_session_maker() as session:
-        workspace_manager = WorkspaceManager(session)
-        workspace = await workspace_manager.get_main()
+        workspace_repository = WorkspaceRepository(session)
+        workspace = await workspace_repository.get_main()
 
         if workspace is None:
             raise MainWorkspaceDoesNotExist()
@@ -54,8 +54,8 @@ async def get_main_fief_workspace() -> Workspace:
 async def get_main_fief_client() -> Client:
     workspace = await get_main_fief_workspace()
     async with get_workspace_session(workspace) as session:
-        client_manager = ClientManager(session)
-        client = await client_manager.get_by_client_id(settings.fief_client_id)
+        client_repository = ClientRepository(session)
+        client = await client_repository.get_by_client_id(settings.fief_client_id)
 
         if client is None:
             raise MainWorkspaceClientDoesNotExist()
@@ -67,9 +67,9 @@ async def create_main_fief_workspace() -> Workspace:
     from fief.services.workspace_creation import WorkspaceCreation
 
     async with main_async_session_maker() as session:
-        workspace_manager = WorkspaceManager(session)
-        workspace_user_manager = WorkspaceUserManager(session)
-        workspace = await workspace_manager.get_main()
+        workspace_repository = WorkspaceRepository(session)
+        workspace_user_repository = WorkspaceUserRepository(session)
+        workspace = await workspace_repository.get_main()
 
         if workspace is not None:
             raise MainWorkspaceAlreadyExists()
@@ -77,7 +77,7 @@ async def create_main_fief_workspace() -> Workspace:
         workspace_create = WorkspaceCreate(name="Fief")
         workspace_db = WorkspaceDatabase()
         workspace_creation = WorkspaceCreation(
-            workspace_manager, workspace_user_manager, workspace_db
+            workspace_repository, workspace_user_repository, workspace_db
         )
 
         workspace = await workspace_creation.create(
@@ -100,11 +100,11 @@ async def create_main_fief_user(email: str, password: str) -> User:
     workspace = await get_main_fief_workspace()
 
     async with main_async_session_maker() as session:
-        workspace_user_manager = WorkspaceUserManager(session)
+        workspace_user_repository = WorkspaceUserRepository(session)
 
         async with get_workspace_session(workspace) as session:
-            tenant_manager = TenantManager(session)
-            tenant = await tenant_manager.get_default()
+            tenant_repository = TenantRepository(session)
+            tenant = await tenant_repository.get_default()
 
             if tenant is None:
                 raise MainWorkspaceDoesNotHaveDefaultTenant()
@@ -122,6 +122,6 @@ async def create_main_fief_user(email: str, password: str) -> User:
             )
 
         workspace_user = WorkspaceUser(workspace_id=workspace.id, user_id=user.id)
-        await workspace_user_manager.create(workspace_user)
+        await workspace_user_repository.create(workspace_user)
 
     return user
